"""
Play elevator music in the background while your script runs.
"""
from script_background_music.play import play_music_in_background, play_random_music_in_background, \
    play_song_in_background
from script_background_music.context import BackgroundMusicContext
